Print

Print


Commit in lcdd/src on MAIN
G4NonprojectiveCylinderSegmentation.cc+5-51.11 -> 1.12
phi computed using mid-radius rather than inner radius of current slice.

lcdd/src
G4NonprojectiveCylinderSegmentation.cc 1.11 -> 1.12
diff -u -r1.11 -r1.12
--- G4NonprojectiveCylinderSegmentation.cc	22 Jun 2005 22:20:30 -0000	1.11
+++ G4NonprojectiveCylinderSegmentation.cc	23 Jun 2005 23:42:45 -0000	1.12
@@ -1,4 +1,4 @@
-// $Header: /cvs/lcd/lcdd/src/G4NonprojectiveCylinderSegmentation.cc,v 1.11 2005/06/22 22:20:30 jeremy Exp $
+// $Header: /cvs/lcd/lcdd/src/G4NonprojectiveCylinderSegmentation.cc,v 1.12 2005/06/23 23:42:45 jeremy Exp $
 #include "G4NonprojectiveCylinderSegmentation.hh"
 
 #include "ReadoutUtil.hh"
@@ -83,11 +83,11 @@
 
 double G4NonprojectiveCylinderSegmentation::computeDeltaPhi(const G4Step* aStep)
 {
-  // inner radius of current tubs
-  double irad_layer = ReadoutUtil::getTubs( aStep )->GetInnerRadius();
+  // mid radius of current tubs
+  double mid_rad_layer = ReadoutUtil::computeTubsMidRadius( aStep );
 
-  // circumfrance of current tubs
-  double circ = 2.0 * ReadoutUtil::PI * irad_layer;
+  // circumference of current tubs
+  double circ = 2.0 * ReadoutUtil::PI * mid_rad_layer;
 
   // number of cells along phi in curr layer
   int nphi = (int)floor( circ / m_gridSizePhi );
CVSspam 0.2.8